@@ -4,7 +4,10 @@ DATABASES = {
         'NAME': 'testproject/test.db3'
     }
 }
-INSTALLED_APPS = ["picklefield"]
+INSTALLED_APPS = [
+    'django.contrib.contenttypes',
+    'picklefield',
+]
 SITE_ID = 1
-ROOT_URLCONF = "testproject.urls"
-SECRET_KEY = "1"
+ROOT_URLCONF = 'testproject.urls'
+SECRET_KEY = '1'
